﻿'(C) Copyright 2011 by Autodesk, Inc. 

'Permission to use, copy, modify, and distribute this software
'in object code form for any purpose and without fee is hereby
'granted, provided that the above copyright notice appears in
'all copies and that both that copyright notice and the limited
'warranty and restricted rights notice below appear in all
'supporting documentation.

'AUTODESK PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS. 
'AUTODESK SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
'MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE.  AUTODESK,
'INC. DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL
'BE UNINTERRUPTED OR ERROR FREE.

'Use, duplication, or disclosure by the U.S. Government is
'subject to restrictions set forth in FAR 52.227-19 (Commercial
'Computer Software - Restricted Rights) and DFAR 252.227-7013(c)
'(1)(ii)(Rights in Technical Data and Computer Software), as
'applicable.


Imports System
Imports System.Type
Imports System.Activator
Imports System.Runtime.InteropServices
Imports Inventor

Public Class Form1

    Dim _invApp As Inventor.Application
    Dim _started As Boolean

    Public Sub New()

        ' This call is required by the designer.
        InitializeComponent()

        ' Add any initialization after the InitializeComponent() call.
        Try
            _invApp = Marshal.GetActiveObject("Inventor.Application")

        Catch ex As Exception
            Try
                Dim oInvAppType As Type = _
                  GetTypeFromProgID("Inventor.Application")

                _invApp = CreateInstance(oInvAppType)
                _invApp.Visible = True

                'Note: if you shut down the Inventor session that was started
                'this(way) there is still an Inventor.exe running. We will use
                'this Boolean to test whether or not the Inventor App  will
                'need to be shut down.
                _started = True

            Catch ex2 As Exception
                MsgBox(ex2.ToString())
                MsgBox("Unable to get or start Inventor")
            End Try
        End Try

    End Sub


    Private Sub Form1_FormClosed( _
      ByVal sender As Object, ByVal e As FormClosedEventArgs) _
      Handles Me.FormClosed

        If _started Then
            _invApp.Quit()
        End If

        _invApp = Nothing

    End Sub


    Private Sub Button1_Click( _
      ByVal sender As Object, ByVal e As System.EventArgs) _
      Handles Button1.Click

        AddOrRemoveFromGroup(True)

    End Sub


    Private Sub Button2_Click( _
      ByVal sender As System.Object, ByVal e As EventArgs) _
      Handles Button2.Click

        HideOrShowGroup(False)

    End Sub
    Public Sub HideOrShowGroup(ByVal hide As Boolean)
        If _invApp.Documents.Count = 0 Then
            MsgBox("Need to open an Assembly document")
            Return
        End If

        If _invApp.ActiveDocument.DocumentType <> _
             DocumentTypeEnum.kAssemblyDocumentObject Then
            MsgBox("Need to have an Assembly document active")
            Return
        End If

        Dim asmDoc As AssemblyDocument
        asmDoc = _invApp.ActiveDocument

        Try

            Dim attbMan As AttributeManager = asmDoc.AttributeManager

            Dim objsCol As ObjectCollection
            objsCol = _
              attbMan.FindObjects("myPartGroup", "PartGroup1", "Group1")

            Dim compOcc As ComponentOccurrence
            For Each obj As Object In objsCol
                compOcc = obj
                compOcc.Visible = hide 'False
            Next

        Catch ex As Exception
            MsgBox("Problem hiding component")
        End Try
    End Sub

    Private Sub Button3_Click( _
      ByVal sender As System.Object, ByVal e As System.EventArgs) _
      Handles Button3.Click

        HideOrShowGroup(True)
    End Sub

    Public Sub AddOrRemoveFromGroup(ByVal add As Boolean)
        If _invApp.Documents.Count = 0 Then
            MsgBox("Need to open an Assembly document")
            Return
        End If

        If _invApp.ActiveDocument.DocumentType <> _
             DocumentTypeEnum.kAssemblyDocumentObject Then
            MsgBox("Need to have an Assembly document active")
            Return
        End If

        Dim asmDoc As AssemblyDocument
        asmDoc = _invApp.ActiveDocument

        If asmDoc.SelectSet.Count = 0 Then
            MsgBox("Need to select a Part or Sub Assembly")
            Return
        End If

        Dim selSet As SelectSet
        selSet = asmDoc.SelectSet

        Try
            Dim compOcc As ComponentOccurrence
            Dim obj As Object
            For Each obj In selSet
                compOcc = obj
                Debug.Print(compOcc.Name)

                Dim attbSets As AttributeSets = compOcc.AttributeSets

                If add Then
                    ' Add the attributes to the ComponentOccurrence
                    If Not attbSets.NameIsUsed("myPartGroup") Then

                        Dim attbSet As AttributeSet = attbSets.Add("myPartGroup")

                        Dim attb As Inventor.Attribute = _
                          attbSet.Add( _
                            "PartGroup1", ValueTypeEnum.kStringType, "Group1")

                    End If
                Else
                    ' Delete the attributes to the ComponentOccurrence
                    If attbSets.NameIsUsed("myPartGroup") Then
                        attbSets.Item("myPartGroup").Delete()
                    End If

                End If

                'compOcc.Visible = False

            Next
        Catch ex As Exception
            MsgBox("Is the selected item a Component?")
            MsgBox(ex.ToString())
            Return
        End Try
    End Sub

    Private Sub Button4_Click( _
      ByVal sender As System.Object, ByVal e As System.EventArgs) _
      Handles Button4.Click

        AddOrRemoveFromGroup(False)
    End Sub

    Private Sub Button5_Click( _
      ByVal sender As System.Object, ByVal e As System.EventArgs) _
      Handles Button5.Click

        If _invApp.Documents.Count = 0 Then
            MsgBox("Need to open an Assembly document")
            Return
        End If

        If _invApp.ActiveDocument.DocumentType <> _
            DocumentTypeEnum.kAssemblyDocumentObject Then
            MsgBox("Need to have an Assembly document active")
            Return
        End If

        Dim asmDoc As AssemblyDocument = _invApp.ActiveDocument
        ' Get the attribute manager for the document
        Dim attbMan As AttributeManager = asmDoc.AttributeManager

        ' Find the objects with the attributes
        Dim objCol As ObjectCollection
        objCol = _
          attbMan.FindObjects("myPartGroup", "PartGroup1", "Group1")

        Dim attbSets As AttributeSets

        ' Delete the attribute from the ComponentOccurrence
        For Each obj As Object In objCol
            attbSets = obj.AttributeSets
            attbSets.Item("myPartGroup").Delete()
            ' Make the ComponentOccurrence visible
            obj.Visible = True
        Next
    End Sub


End Class